@@ -19,7 +19,7 @@ static void
 printfeed(FILE *fp, struct feed *f)
 {
 	char *fields[FieldLast];
-	struct tm *tm;
+	struct tm rtm, *tm;
 	time_t parsedtime;
 	unsigned int isnew;
 	ssize_t linelen;
@@ -42,7 +42,7 @@ printfeed(FILE *fp, struct feed *f)
 
 		parsedtime = 0;
 		if (!strtotime(fields[FieldUnixTimestamp], &parsedtime) &&
-		    (tm = localtime(&parsedtime))) {
+		    (tm = localtime_r(&parsedtime, &rtm))) {
 			isnew = (parsedtime >= comparetime) ? 1 : 0;
 			totalnew += isnew;
 			f->totalnew += isnew;
