@@ -9,7 +9,7 @@
 
 static char *line;
 static size_t linesize;
-static char host[256], *user, mtimebuf[32];
+static char host[256], *user, dtimebuf[32], mtimebuf[32];
 
 static unsigned long
 djb2(unsigned char *s, unsigned long hash)
@@ -24,8 +24,8 @@ djb2(unsigned char *s, unsigned long hash)
 static void
 printfeed(FILE *fp, const char *feedname)
 {
-	struct tm tm;
 	char *fields[FieldLast], timebuf[32];
+	struct tm *tm;
 	time_t parsedtime;
 	unsigned long hash;
 	ssize_t linelen;
@@ -34,28 +34,23 @@ printfeed(FILE *fp, const char *feedname)
 		if (line[linelen - 1] == '\n')
 			line[--linelen] = '\0';
 		hash = djb2((unsigned char *)line, 5381UL);
-		if (!parseline(line, fields))
-			break;
-		parsedtime = 0;
-		if (strtotime(fields[FieldUnixTimestamp], &parsedtime))
-			continue;
+		parseline(line, fields);
 
 		/* mbox + mail header */
 		printf("From MAILER-DAEMON %s\n", mtimebuf);
-		/* can't convert: default to formatted time for time_t 0. */
-		if (gmtime_r(&parsedtime, &tm) &&
-		    strftime(timebuf, sizeof(timebuf),
-		             "%a, %d %b %Y %H:%M:%S +0000", &tm))
-			printf("Date: %s\n", timebuf);
-		else
-			printf("Date: Thu, 01 Jan 1970 00:00:00 +0000\n");
 
-		printf("From: %s <sfeed@>\n", fields[FieldAuthor][0] ? fields[FieldAuthor] : "unknown");
+		parsedtime = 0;
+		if (!strtotime(fields[FieldUnixTimestamp], &parsedtime) &&
+		    (tm = gmtime(&parsedtime)) &&
+		    strftime(timebuf, sizeof(timebuf), "%a, %d %b %Y %H:%M:%S +0000", tm)) {
+			printf("Date: %s\n", timebuf);
+		} else {
+			printf("Date: %s\n", dtimebuf); /* invalid/missing: use current time */
+		}
+
+		printf("From: %s <sfeed@>\n", fields[FieldAuthor][0] ? fields[FieldAuthor] : feedname);
 		printf("To: %s <%s@%s>\n", user, user, host);
-		if (feedname[0])
-			printf("Subject: [%s] %s\n", feedname, fields[FieldTitle]);
-		else
-			printf("Subject: %s\n", fields[FieldTitle]);
+		printf("Subject: %s\n", fields[FieldTitle]);
 		printf("Message-ID: <%s%s%lu@%s>\n",
 		       fields[FieldUnixTimestamp],
 		       fields[FieldUnixTimestamp][0] ? "." : "",
@@ -74,8 +69,8 @@ printfeed(FILE *fp, const char *feedname)
 int
 main(int argc, char *argv[])
 {
-	struct tm tm;
-	time_t t;
+	struct tm tmnow;
+	time_t now;
 	FILE *fp;
 	char *name;
 	int i;
@@ -87,11 +82,13 @@ main(int argc, char *argv[])
 		user = "you";
 	if (gethostname(host, sizeof(host)) == -1)
 		err(1, "gethostname");
-	if ((t = time(NULL)) == -1)
+	if ((now = time(NULL)) == -1)
 		err(1, "time");
-	if (!gmtime_r(&t, &tm))
-		errx(1, "gmtime_r: can't get current time");
-	if (!strftime(mtimebuf, sizeof(mtimebuf), "%a %b %d %H:%M:%S %Y", &tm))
+	if (!gmtime_r(&now, &tmnow))
+		err(1, "gmtime_r: can't get current time");
+	if (!strftime(mtimebuf, sizeof(mtimebuf), "%a %b %d %H:%M:%S %Y", &tmnow))
+		errx(1, "strftime: can't format current time");
+	if (!strftime(dtimebuf, sizeof(dtimebuf), "%a, %d %b %Y %H:%M:%S +0000", &tmnow))
 		errx(1, "strftime: can't format current time");
 
 	if (argc == 1) {
