@@ -21,18 +21,17 @@ printfeed(FILE *fp, const char *feedname)
 	while ((linelen = getline(&line, &linesize, fp)) > 0) {
 		if (line[linelen - 1] == '\n')
 			line[--linelen] = '\0';
-		if (!parseline(line, fields))
-			break;
+		parseline(line, fields);
 
 		parsedtime = 0;
-		if (strtotime(fields[FieldUnixTimestamp], &parsedtime))
-			continue;
-		if (!(tm = gmtime(&parsedtime)))
-			err(1, "localtime");
-
-		fprintf(stdout, "%04d-%02d-%02dT%02d:%02d:%02dZ\t",
-		        tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
-		        tm->tm_hour, tm->tm_min, tm->tm_sec);
+		if (!strtotime(fields[FieldUnixTimestamp], &parsedtime) &&
+		    (tm = gmtime(&parsedtime))) {
+			fprintf(stdout, "%04d-%02d-%02dT%02d:%02d:%02dZ\t",
+			        tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
+			        tm->tm_hour, tm->tm_min, tm->tm_sec);
+		} else {
+			fputs("\t", stdout);
+		}
 		if (feedname[0])
 			printf("[%s] ", feedname);
 		fputs(fields[FieldTitle], stdout);
